==> film_gyaan-1.0.1.tar.gz: lib/src/dx/_endpoints/movies.dart <==
// coverage:ignore-file
import 'package:film_gyaan/core.dart';

/// A parameter class which will be used to make the initial request for
/// getting the popular movies.
class PopularMoviesParams extends Parameters {
  /// [page] : Page number to get the set of movies for a particular page.
  PopularMoviesParams({
    this.page = 1,
  });

  int page;

  @override
  Request toRequest() => Request.get(
        uri: Uri(
          path: '/3/movie/popular',
          queryParameters: <String, dynamic>{
            'page': page.toString(),
          },
        ),
      );
}

/// A parameter class which will be used to make the initial request for
/// getting the now playing movies.
class NowPlayingMoviesParams extends Parameters {
  /// [page] : Page number to get the set of movies for a particular page.
  NowPlayingMoviesParams({
    this.page = 1,
  });

  int page;

  @override
  Request toRequest() => Request.get(
        uri: Uri(
          path: '/3/movie/now_playing',
          queryParameters: <String, dynamic>{
            'page': page.toString(),
          },
        ),
      );
}

/// A parameter class which will be used to make the initial request for
/// getting the upcoming movies.
class UpcomingMoviesParams extends Parameters {
  /// [page] : Page number to get the set of movies for a particular page.
  UpcomingMoviesParams({
    this.page = 1,
  });

  int page;

  @override
  Request toRequest() => Request.get(
        uri: Uri(
          path: '/3/movie/upcoming',
          queryParameters: <String, dynamic>{
            'page': page.toString(),
          },
        ),
      );
}

/// A parameter class which will be used to make the initial request for
/// getting the top rated movies.
class TopRatedMoviesParams extends Parameters {
  /// [page] : Page number to get the set of movies for a particular page.
  TopRatedMoviesParams({
    this.page = 1,
  });

  int page;

  @override
  Request toRequest() => Request.get(
        uri: Uri(
          path: '/3/movie/top_rated',
          queryParameters: <String, dynamic>{
            'page': page.toString(),
          },
        ),
      );
}

/// A parameter class which will be used to make the initial request for
/// getting the latest movie.
class LatestMovieParams extends Parameters {
  @override
  Request toRequest() => Request.get(
        uri: Uri(
          path: '/3/movie/latest',
        ),
      );
}

/// A parameter class which will be used to make the initial request for
/// getting the movie details.
class MovieInformationParams extends Parameters {
  /// [movieId] : Id of the movie
  MovieInformationParams({
    required this.movieId,
  });

  int movieId;

  @override
  Request toRequest() => Request.get(
        uri: Uri(
          path: '/3/movie/$movieId',
          queryParameters: <String, dynamic>{
            'append_to_response': 'videos,images,credits,reviews,recommendations,similar,external_ids',
          },
        ),
      );
}

/// A parameter class which will be used to make the initial request for
/// getting the alternative titles of movie.
class AlternativeTitlesParams extends Parameters {
  /// [movieId] : Id of the movie
  AlternativeTitlesParams({
    required this.movieId,
  });

  int movieId;

  @override
  Request toRequest() => Request.get(
        uri: Uri(
          path: '/3/movie/$movieId/alternative_titles',
        ),
      );
}

/// A parameter class which will be used to make the initial request for
/// getting the credits of the movie.
class CreditsParams extends Parameters {
  /// [movieId] : Id of the movie
  CreditsParams({
    required this.movieId,
  });

  int movieId;

  @override
  Request toRequest() => Request.get(
        uri: Uri(
          path: '/3/movie/$movieId/credits',
        ),
      );
}

/// A parameter class which will be used to make the initial request for
/// getting the external ids of the movie.
class ExternalIdsParams extends Parameters {
  /// [movieId] : Id of the movie
  ExternalIdsParams({
    required this.movieId,
  });

  int movieId;

  @override
  Request toRequest() => Request.get(
        uri: Uri(
          path: '/3/movie/$movieId/external_ids',
        ),
      );
}

/// A parameter class which will be used to make the initial request for
/// getting the images of the movie.
class ImagesParams extends Parameters {
  /// [movieId] : Id of the movie
  ImagesParams({
    required this.movieId,
  });

  int movieId;

  @override
  Request toRequest() => Request.get(
        uri: Uri(
          path: '/3/movie/$movieId/images',
        ),
      );
}

/// A parameter class which will be used to make the initial request for
/// getting the keywords of the movie.
class KeywordsParams extends Parameters {
  /// [movieId] : Id of the movie
  KeywordsParams({
    required this.movieId,
  });

  int movieId;

  @override
  Request toRequest() => Request.get(
        uri: Uri(
          path: '/3/movie/$movieId/keywords',
        ),
      );
}

/// A parameter class which will be used to make the initial request for
/// getting the lists in which the movie belongs to.
class MovieListsParams extends Parameters {
  /// [page] : Page number to get the set of movies for a particular page.
  /// [movieId] : Id of the movie
  MovieListsParams({
    this.page = 1,
    required this.movieId,
  });

  int page;
  int movieId;

  @override
  Request toRequest() => Request.get(
    uri: Uri(
      path: '/3/movie/$movieId/lists',
      queryParameters: <String, dynamic>{
        'page': page.toString(),
      },
    ),
  );
}

/// A parameter class which will be used to make the initial request for
/// getting the recommended movies related to movie.
class RecommendationsParams extends Parameters {
  /// [page] : Page number to get the set of movies for a particular page.
  /// [movieId] : Id of the movie
  RecommendationsParams({
    this.page = 1,
    required this.movieId,
  });

  int page;
  int movieId;

  @override
  Request toRequest() => Request.get(
    uri: Uri(
      path: '/3/movie/$movieId/recommendations',
      queryParameters: <String, dynamic>{
        'page': page.toString(),
      },
    ),
  );
}

/// A parameter class which will be used to make the initial request for
/// getting the release dates of the movie.
class ReleaseDatesParams extends Parameters {
  /// [movieId] : Id of the movie
  ReleaseDatesParams({
    required this.movieId,
  });

  int movieId;

  @override
  Request toRequest() => Request.get(
    uri: Uri(
      path: '/3/movie/$movieId/release_dates',
    ),
  );
}

/// A parameter class which will be used to make the initial request for
/// getting the reviews related to movie.
class ReviewsParams extends Parameters {
  /// [page] : Page number to get the set of movies for a particular page.
  /// [movieId] : Id of the movie
  ReviewsParams({
    this.page = 1,
    required this.movieId,
  });

  int page;
  int movieId;

  @override
  Request toRequest() => Request.get(
    uri: Uri(
      path: '/3/movie/$movieId/reviews',
      queryParameters: <String, dynamic>{
        'page': page.toString(),
      },
    ),
  );
}

/// A parameter class which will be used to make the initial request for
/// getting the similar movies related to movie.
class SimilarParams extends Parameters {
  /// [page] : Page number to get the set of movies for a particular page.
  /// [movieId] : Id of the movie
  SimilarParams({
    this.page = 1,
    required this.movieId,
  });

  int page;
  int movieId;

  @override
  Request toRequest() => Request.get(
    uri: Uri(
      path: '/3/movie/$movieId/similar',
      queryParameters: <String, dynamic>{
        'page': page.toString(),
      },
    ),
  );
}

/// A parameter class which will be used to make the initial request for
/// getting translations of the movie.
class TranslationsParams extends Parameters {
  /// [movieId] : Id of the movie
  TranslationsParams({
    required this.movieId,
  });

  int movieId;

  @override
  Request toRequest() => Request.get(
    uri: Uri(
      path: '/3/movie/$movieId/translations',
    ),
  );
}

/// A parameter class which will be used to make the initial request for
/// getting videos of the movie.
class VideosParams extends Parameters {
  /// [movieId] : Id of the movie
  VideosParams({
    required this.movieId,
  });

  int movieId;

  @override
  Request toRequest() => Request.get(
    uri: Uri(
      path: '/3/movie/$movieId/videos',
    ),
  );
}

==> film_gyaan-1.0.2.tar.gz: lib/src/dx/_endpoints/movies.dart <==
// coverage:ignore-file
import 'package:film_gyaan/core.dart';

/// A parameter class which will be used to make the initial request for
/// getting the popular movies.
class PopularMoviesParams extends Parameters {
  /// [page] : Page number to get the set of movies for a particular page.
  PopularMoviesParams({
    this.page = 1,
  });

  int page;

  @override
  Request toRequest() => Request.get(
        uri: Uri(
          path: '/3/movie/popular',
          queryParameters: <String, dynamic>{
            'page': page.toString(),
          },
        ),
      );
}

/// A parameter class which will be used to make the initial request for
/// getting the now playing movies.
class NowPlayingMoviesParams extends Parameters {
  /// [page] : Page number to get the set of movies for a particular page.
  NowPlayingMoviesParams({
    this.page = 1,
  });

  int page;

  @override
  Request toRequest() => Request.get(
        uri: Uri(
          path: '/3/movie/now_playing',
          queryParameters: <String, dynamic>{
            'page': page.toString(),
          },
        ),
      );
}

/// A parameter class which will be used to make the initial request for
/// getting the upcoming movies.
class UpcomingMoviesParams extends Parameters {
  /// [page] : Page number to get the set of movies for a particular page.
  UpcomingMoviesParams({
    this.page = 1,
  });

  int page;

  @override
  Request toRequest() => Request.get(
        uri: Uri(
          path: '/3/movie/upcoming',
          queryParameters: <String, dynamic>{
            'page': page.toString(),
          },
        ),
      );
}

/// A parameter class which will be used to make the initial request for
/// getting the top rated movies.
class TopRatedMoviesParams extends Parameters {
  /// [page] : Page number to get the set of movies for a particular page.
  TopRatedMoviesParams({
    this.page = 1,
  });

  int page;

  @override
  Request toRequest() => Request.get(
        uri: Uri(
          path: '/3/movie/top_rated',
          queryParameters: <String, dynamic>{
            'page': page.toString(),
          },
        ),
      );
}

/// A parameter class which will be used to make the initial request for
/// getting the latest movie.
class LatestMovieParams extends Parameters {
  @override
  Request toRequest() => Request.get(
        uri: Uri(
          path: '/3/movie/latest',
        ),
      );
}

/// A parameter class which will be used to make the initial request for
/// getting the movie details.
class MovieInformationParams extends Parameters {
  /// [movieId] : Id of the movie
  MovieInformationParams({
    required this.movieId,
  });

  int movieId;

  @override
  Request toRequest() => Request.get(
        uri: Uri(
          path: '/3/movie/$movieId',
          queryParameters: <String, dynamic>{
            'append_to_response':
                'videos,images,credits,reviews,recommendations,similar,external_ids',
          },
        ),
      );
}

/// A parameter class which will be used to make the initial request for
/// getting the alternative titles of movie.
class AlternativeTitlesParams extends Parameters {
  /// [movieId] : Id of the movie
  AlternativeTitlesParams({
    required this.movieId,
  });

  int movieId;

  @override
  Request toRequest() => Request.get(
        uri: Uri(
          path: '/3/movie/$movieId/alternative_titles',
        ),
      );
}

/// A parameter class which will be used to make the initial request for
/// getting the credits of the movie.
class CreditsParams extends Parameters {
  /// [movieId] : Id of the movie
  CreditsParams({
    required this.movieId,
  });

  int movieId;

  @override
  Request toRequest() => Request.get(
        uri: Uri(
          path: '/3/movie/$movieId/credits',
        ),
      );
}

/// A parameter class which will be used to make the initial request for
/// getting the external ids of the movie.
class ExternalIdsParams extends Parameters {
  /// [movieId] : Id of the movie
  ExternalIdsParams({
    required this.movieId,
  });

  int movieId;

  @override
  Request toRequest() => Request.get(
        uri: Uri(
          path: '/3/movie/$movieId/external_ids',
        ),
      );
}

/// A parameter class which will be used to make the initial request for
/// getting the images of the movie.
class ImagesParams extends Parameters {
  /// [movieId] : Id of the movie
  ImagesParams({
    required this.movieId,
  });

  int movieId;

  @override
  Request toRequest() => Request.get(
        uri: Uri(
          path: '/3/movie/$movieId/images',
        ),
      );
}

/// A parameter class which will be used to make the initial request for
/// getting the keywords of the movie.
class KeywordsParams extends Parameters {
  /// [movieId] : Id of the movie
  KeywordsParams({
    required this.movieId,
  });

  int movieId;

  @override
  Request toRequest() => Request.get(
        uri: Uri(
          path: '/3/movie/$movieId/keywords',
        ),
      );
}

/// A parameter class which will be used to make the initial request for
/// getting the lists in which the movie belongs to.
class MovieListsParams extends Parameters {
  /// [page] : Page number to get the set of movies for a particular page.
  /// [movieId] : Id of the movie
  MovieListsParams({
    this.page = 1,
    required this.movieId,
  });

  int page;
  int movieId;

  @override
  Request toRequest() => Request.get(
        uri: Uri(
          path: '/3/movie/$movieId/lists',
          queryParameters: <String, dynamic>{
            'page': page.toString(),
          },
        ),
      );
}

/// A parameter class which will be used to make the initial request for
/// getting the recommended movies related to movie.
class RecommendationsParams extends Parameters {
  /// [page] : Page number to get the set of movies for a particular page.
  /// [movieId] : Id of the movie
  RecommendationsParams({
    this.page = 1,
    required this.movieId,
  });

  int page;
  int movieId;

  @override
  Request toRequest() => Request.get(
        uri: Uri(
          path: '/3/movie/$movieId/recommendations',
          queryParameters: <String, dynamic>{
            'page': page.toString(),
          },
        ),
      );
}

/// A parameter class which will be used to make the initial request for
/// getting the release dates of the movie.
class ReleaseDatesParams extends Parameters {
  /// [movieId] : Id of the movie
  ReleaseDatesParams({
    required this.movieId,
  });

  int movieId;

  @override
  Request toRequest() => Request.get(
        uri: Uri(
          path: '/3/movie/$movieId/release_dates',
        ),
      );
}

/// A parameter class which will be used to make the initial request for
/// getting the reviews related to movie.
class ReviewsParams extends Parameters {
  /// [page] : Page number to get the set of movies for a particular page.
  /// [movieId] : Id of the movie
  ReviewsParams({
    this.page = 1,
    required this.movieId,
  });

  int page;
  int movieId;

  @override
  Request toRequest() => Request.get(
        uri: Uri(
          path: '/3/movie/$movieId/reviews',
          queryParameters: <String, dynamic>{
            'page': page.toString(),
          },
        ),
      );
}

/// A parameter class which will be used to make the initial request for
/// getting the similar movies related to movie.
class SimilarParams extends Parameters {
  /// [page] : Page number to get the set of movies for a particular page.
  /// [movieId] : Id of the movie
  SimilarParams({
    this.page = 1,
    required this.movieId,
  });

  int page;
  int movieId;

  @override
  Request toRequest() => Request.get(
        uri: Uri(
          path: '/3/movie/$movieId/similar',
          queryParameters: <String, dynamic>{
            'page': page.toString(),
          },
        ),
      );
}

/// A parameter class which will be used to make the initial request for
/// getting translations of the movie.
class TranslationsParams extends Parameters {
  /// [movieId] : Id of the movie
  TranslationsParams({
    required this.movieId,
  });

  int movieId;

  @override
  Request toRequest() => Request.get(
        uri: Uri(
          path: '/3/movie/$movieId/translations',
        ),
      );
}

/// A parameter class which will be used to make the initial request for
/// getting videos of the movie.
class VideosParams extends Parameters {
  /// [movieId] : Id of the movie
  VideosParams({
    required this.movieId,
  });

  int movieId;

  @override
  Request toRequest() => Request.get(
        uri: Uri(
          path: '/3/movie/$movieId/videos',
        ),
      );
}
